// Verilog code generation for filter with 106 taps and 118 non-zero bits
// Filter has a coefficient wordlength of 13 bits and a data wordsize of 16 bits
// CSEs are {101, 10-1, 1001, and 100-1}

module filt_CSE_1(Xin, CSE_O_1);
	input [15:0] Xin;
	output [18:0] CSE_O_1;
	assign CSE_O_1 = {{{{3{Xin[15]}}, Xin[15:2]} + {{1{Xin[15]}}, Xin[15:0]}}, Xin[1:0]};
endmodule

module filt_CSE_2(Xin, CSE_O_2);
	input [15:0] Xin;
	output [17:0] CSE_O_2;
	assign CSE_O_2 = {{{{2{Xin[15]}}, Xin[15:2]} - Xin[15:0]}, Xin[1:0]};
endmodule

module filt_CSE_3(Xin, CSE_O_3);
	input [15:0] Xin;
	output [19:0] CSE_O_3;
	assign CSE_O_3 = {{{{3{Xin[15]}}, Xin[15:3]} + {{1{Xin[15]}}, Xin[15:0]}}, Xin[2:0]};
endmodule

module filt_CSE_4(Xin, CSE_O_4);
	input [15:0] Xin;
	output [18:0] CSE_O_4;
	assign CSE_O_4 = {{{{2{Xin[15]}}, Xin[15:3]} - Xin[15:0]}, Xin[2:0]};
endmodule

module filt_0(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In2_0, Out1_0, Out2_0);
// Value of filter coefficient is: 0.0004882812500000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In2_0;
	output [29:0] Out1_0, Out2_0;
	reg [29:0] Out1_0, Out2_0;

	wire [29:0] Mult_out;

	assign Mult_out = {{12{Xin[15]}}, Xin[15:0], 2'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_0 <= 0;
			Out2_0 <= 0;
			end
		else begin
			Out1_0 <= Mult_out;
			Out2_0 <= In2_0 + Mult_out;
			end
endmodule

module filt_1(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_1, In2_1, Out1_1, Out2_1);
// Value of filter coefficient is: 0.0002441406250000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_1, In2_1;
	output [29:0] Out1_1, Out2_1;
	reg [29:0] Out1_1, Out2_1;

	wire [29:0] Mult_out;

	assign Mult_out = {{13{Xin[15]}}, Xin[15:0], 1'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_1 <= 0;
			Out2_1 <= 0;
			end
		else begin
			Out1_1 <= In1_1 + Mult_out;
			Out2_1 <= In2_1 + Mult_out;
			end
endmodule

module filt_2(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_2, In2_2, Out1_2, Out2_2);
// Value of filter coefficient is: 0.0003662109375000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_2, In2_2;
	output [29:0] Out1_2, Out2_2;
	reg [29:0] Out1_2, Out2_2;

	wire [29:0] Mult_out;

	assign Mult_out = {{11{CSE_I_2[17]}}, CSE_I_2[17:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_2 <= 0;
			Out2_2 <= 0;
			end
		else begin
			Out1_2 <= In1_2 - Mult_out;
			Out2_2 <= In2_2 - Mult_out;
			end
endmodule

module filt_3(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_3, In2_3, Out1_3, Out2_3);
// Value of filter coefficient is: 0.0002441406250000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_3, In2_3;
	output [29:0] Out1_3, Out2_3;
	reg [29:0] Out1_3, Out2_3;

	wire [29:0] Mult_out;

	assign Mult_out = {{13{Xin[15]}}, Xin[15:0], 1'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_3 <= 0;
			Out2_3 <= 0;
			end
		else begin
			Out1_3 <= In1_3 + Mult_out;
			Out2_3 <= In2_3 + Mult_out;
			end
endmodule

module filt_4(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_4, In2_4, Out1_4, Out2_4);
// Value of filter coefficient is: 0.0001220703125000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_4, In2_4;
	output [29:0] Out1_4, Out2_4;
	reg [29:0] Out1_4, Out2_4;

	wire [29:0] Mult_out;

	assign Mult_out = {{14{Xin[15]}}, Xin[15:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_4 <= 0;
			Out2_4 <= 0;
			end
		else begin
			Out1_4 <= In1_4 + Mult_out;
			Out2_4 <= In2_4 + Mult_out;
			end
endmodule

module filt_5(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_5, In2_5, Out1_5, Out2_5);
// Value of filter coefficient is: 0.0000000000000000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_5, In2_5;
	output [29:0] Out1_5, Out2_5;
	reg [29:0] Out1_5, Out2_5;

	wire [29:0] Mult_out;

	assign Mult_out = 30'b0;

	always @(posedge Clk)
		if (Reset) begin
			Out1_5 <= 0;
			Out2_5 <= 0;
			end
		else begin
			Out1_5 <= In1_5 + Mult_out;
			Out2_5 <= In2_5 + Mult_out;
			end
endmodule

module filt_6(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_6, In2_6, Out1_6, Out2_6);
// Value of filter coefficient is: -0.0002441406250000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_6, In2_6;
	output [29:0] Out1_6, Out2_6;
	reg [29:0] Out1_6, Out2_6;

	wire [29:0] Mult_out;

	assign Mult_out = {{13{Xin[15]}}, Xin[15:0], 1'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_6 <= 0;
			Out2_6 <= 0;
			end
		else begin
			Out1_6 <= In1_6 - Mult_out;
			Out2_6 <= In2_6 - Mult_out;
			end
endmodule

module filt_7(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_7, In2_7, Out1_7, Out2_7);
// Value of filter coefficient is: -0.0004882812500000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_7, In2_7;
	output [29:0] Out1_7, Out2_7;
	reg [29:0] Out1_7, Out2_7;

	wire [29:0] Mult_out;

	assign Mult_out = {{12{Xin[15]}}, Xin[15:0], 2'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_7 <= 0;
			Out2_7 <= 0;
			end
		else begin
			Out1_7 <= In1_7 - Mult_out;
			Out2_7 <= In2_7 - Mult_out;
			end
endmodule

module filt_8(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_8, In2_8, Out1_8, Out2_8);
// Value of filter coefficient is: -0.0008544921875000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_8, In2_8;
	output [29:0] Out1_8, Out2_8;
	reg [29:0] Out1_8, Out2_8;

	wire [29:0] Mult_out;

	assign Mult_out = {{10{CSE_I_4[18]}}, CSE_I_4[18:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_8 <= 0;
			Out2_8 <= 0;
			end
		else begin
			Out1_8 <= In1_8 + Mult_out;
			Out2_8 <= In2_8 + Mult_out;
			end
endmodule

module filt_9(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_9, In2_9, Out1_9, Out2_9);
// Value of filter coefficient is: -0.0009765625000000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_9, In2_9;
	output [29:0] Out1_9, Out2_9;
	reg [29:0] Out1_9, Out2_9;

	wire [29:0] Mult_out;

	assign Mult_out = {{11{Xin[15]}}, Xin[15:0], 3'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_9 <= 0;
			Out2_9 <= 0;
			end
		else begin
			Out1_9 <= In1_9 - Mult_out;
			Out2_9 <= In2_9 - Mult_out;
			end
endmodule

module filt_10(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_10, In2_10, Out1_10, Out2_10);
// Value of filter coefficient is: -0.0008544921875000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_10, In2_10;
	output [29:0] Out1_10, Out2_10;
	reg [29:0] Out1_10, Out2_10;

	wire [29:0] Mult_out;

	assign Mult_out = {{10{CSE_I_4[18]}}, CSE_I_4[18:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_10 <= 0;
			Out2_10 <= 0;
			end
		else begin
			Out1_10 <= In1_10 + Mult_out;
			Out2_10 <= In2_10 + Mult_out;
			end
endmodule

module filt_11(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_11, In2_11, Out1_11, Out2_11);
// Value of filter coefficient is: -0.0008544921875000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_11, In2_11;
	output [29:0] Out1_11, Out2_11;
	reg [29:0] Out1_11, Out2_11;

	wire [29:0] Mult_out;

	assign Mult_out = {{10{CSE_I_4[18]}}, CSE_I_4[18:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_11 <= 0;
			Out2_11 <= 0;
			end
		else begin
			Out1_11 <= In1_11 + Mult_out;
			Out2_11 <= In2_11 + Mult_out;
			end
endmodule

module filt_12(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_12, In2_12, Out1_12, Out2_12);
// Value of filter coefficient is: -0.0004882812500000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_12, In2_12;
	output [29:0] Out1_12, Out2_12;
	reg [29:0] Out1_12, Out2_12;

	wire [29:0] Mult_out;

	assign Mult_out = {{12{Xin[15]}}, Xin[15:0], 2'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_12 <= 0;
			Out2_12 <= 0;
			end
		else begin
			Out1_12 <= In1_12 - Mult_out;
			Out2_12 <= In2_12 - Mult_out;
			end
endmodule

module filt_13(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_13, In2_13, Out1_13, Out2_13);
// Value of filter coefficient is: 0.0000000000000000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_13, In2_13;
	output [29:0] Out1_13, Out2_13;
	reg [29:0] Out1_13, Out2_13;

	wire [29:0] Mult_out;

	assign Mult_out = 30'b0;

	always @(posedge Clk)
		if (Reset) begin
			Out1_13 <= 0;
			Out2_13 <= 0;
			end
		else begin
			Out1_13 <= In1_13 + Mult_out;
			Out2_13 <= In2_13 + Mult_out;
			end
endmodule

module filt_14(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_14, In2_14, Out1_14, Out2_14);
// Value of filter coefficient is: 0.0004882812500000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_14, In2_14;
	output [29:0] Out1_14, Out2_14;
	reg [29:0] Out1_14, Out2_14;

	wire [29:0] Mult_out;

	assign Mult_out = {{12{Xin[15]}}, Xin[15:0], 2'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_14 <= 0;
			Out2_14 <= 0;
			end
		else begin
			Out1_14 <= In1_14 + Mult_out;
			Out2_14 <= In2_14 + Mult_out;
			end
endmodule

module filt_15(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_15, In2_15, Out1_15, Out2_15);
// Value of filter coefficient is: 0.0009765625000000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_15, In2_15;
	output [29:0] Out1_15, Out2_15;
	reg [29:0] Out1_15, Out2_15;

	wire [29:0] Mult_out;

	assign Mult_out = {{11{Xin[15]}}, Xin[15:0], 3'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_15 <= 0;
			Out2_15 <= 0;
			end
		else begin
			Out1_15 <= In1_15 + Mult_out;
			Out2_15 <= In2_15 + Mult_out;
			end
endmodule

module filt_16(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_16, In2_16, Out1_16, Out2_16);
// Value of filter coefficient is: 0.0015869140625000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_16, In2_16;
	output [29:0] Out1_16, Out2_16;
	reg [29:0] Out1_16, Out2_16;

	wire [29:0] Mult_out;

	wire [20:0] T_1;
	assign T_1 = {{{{3{CSE_I_2[17]}},CSE_I_2[17:4]}+{{1{Xin[15]}},Xin[15:0]}},CSE_I_2[3:0]};
	assign Mult_out = {{9{T_1[20]}},T_1[20:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_16 <= 0;
			Out2_16 <= 0;
			end
		else begin
			Out1_16 <= In1_16 + Mult_out;
			Out2_16 <= In2_16 + Mult_out;
			end
endmodule

module filt_17(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_17, In2_17, Out1_17, Out2_17);
// Value of filter coefficient is: 0.0018310546875000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_17, In2_17;
	output [29:0] Out1_17, Out2_17;
	reg [29:0] Out1_17, Out2_17;

	wire [29:0] Mult_out;

	wire [20:0] T_1;
	assign T_1 = {{{{5{Xin[15]}},Xin[15:4]}-{{1{Xin[15]}},Xin[15:0]}},Xin[3:0]};
	assign Mult_out = {{9{T_1[20]}},T_1[20:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_17 <= 0;
			Out2_17 <= 0;
			end
		else begin
			Out1_17 <= In1_17 - Mult_out;
			Out2_17 <= In2_17 - Mult_out;
			end
endmodule

module filt_18(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_18, In2_18, Out1_18, Out2_18);
// Value of filter coefficient is: 0.0019531250000000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_18, In2_18;
	output [29:0] Out1_18, Out2_18;
	reg [29:0] Out1_18, Out2_18;

	wire [29:0] Mult_out;

	assign Mult_out = {{10{Xin[15]}}, Xin[15:0], 4'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_18 <= 0;
			Out2_18 <= 0;
			end
		else begin
			Out1_18 <= In1_18 + Mult_out;
			Out2_18 <= In2_18 + Mult_out;
			end
endmodule

module filt_19(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_19, In2_19, Out1_19, Out2_19);
// Value of filter coefficient is: 0.0015869140625000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_19, In2_19;
	output [29:0] Out1_19, Out2_19;
	reg [29:0] Out1_19, Out2_19;

	wire [29:0] Mult_out;

	wire [20:0] T_1;
	assign T_1 = {{{{3{CSE_I_2[17]}},CSE_I_2[17:4]}+{{1{Xin[15]}},Xin[15:0]}},CSE_I_2[3:0]};
	assign Mult_out = {{9{T_1[20]}},T_1[20:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_19 <= 0;
			Out2_19 <= 0;
			end
		else begin
			Out1_19 <= In1_19 + Mult_out;
			Out2_19 <= In2_19 + Mult_out;
			end
endmodule

module filt_20(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_20, In2_20, Out1_20, Out2_20);
// Value of filter coefficient is: 0.0009765625000000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_20, In2_20;
	output [29:0] Out1_20, Out2_20;
	reg [29:0] Out1_20, Out2_20;

	wire [29:0] Mult_out;

	assign Mult_out = {{11{Xin[15]}}, Xin[15:0], 3'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_20 <= 0;
			Out2_20 <= 0;
			end
		else begin
			Out1_20 <= In1_20 + Mult_out;
			Out2_20 <= In2_20 + Mult_out;
			end
endmodule

module filt_21(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_21, In2_21, Out1_21, Out2_21);
// Value of filter coefficient is: 0.0002441406250000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_21, In2_21;
	output [29:0] Out1_21, Out2_21;
	reg [29:0] Out1_21, Out2_21;

	wire [29:0] Mult_out;

	assign Mult_out = {{13{Xin[15]}}, Xin[15:0], 1'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_21 <= 0;
			Out2_21 <= 0;
			end
		else begin
			Out1_21 <= In1_21 + Mult_out;
			Out2_21 <= In2_21 + Mult_out;
			end
endmodule

module filt_22(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_22, In2_22, Out1_22, Out2_22);
// Value of filter coefficient is: -0.0007324218750000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_22, In2_22;
	output [29:0] Out1_22, Out2_22;
	reg [29:0] Out1_22, Out2_22;

	wire [29:0] Mult_out;

	assign Mult_out = {{10{CSE_I_2[17]}}, CSE_I_2[17:0], 1'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_22 <= 0;
			Out2_22 <= 0;
			end
		else begin
			Out1_22 <= In1_22 + Mult_out;
			Out2_22 <= In2_22 + Mult_out;
			end
endmodule

module filt_23(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_23, In2_23, Out1_23, Out2_23);
// Value of filter coefficient is: -0.0018310546875000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_23, In2_23;
	output [29:0] Out1_23, Out2_23;
	reg [29:0] Out1_23, Out2_23;

	wire [29:0] Mult_out;

	wire [20:0] T_1;
	assign T_1 = {{{{5{Xin[15]}},Xin[15:4]}-{{1{Xin[15]}},Xin[15:0]}},Xin[3:0]};
	assign Mult_out = {{9{T_1[20]}},T_1[20:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_23 <= 0;
			Out2_23 <= 0;
			end
		else begin
			Out1_23 <= In1_23 + Mult_out;
			Out2_23 <= In2_23 + Mult_out;
			end
endmodule

module filt_24(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_24, In2_24, Out1_24, Out2_24);
// Value of filter coefficient is: -0.0028076171875000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_24, In2_24;
	output [29:0] Out1_24, Out2_24;
	reg [29:0] Out1_24, Out2_24;

	wire [29:0] Mult_out;

	wire [21:0] T_1;
	assign T_1 = {{{{2{CSE_I_3[19]}},CSE_I_3[19:5]}-{{1{Xin[15]}},Xin[15:0]}},CSE_I_3[4:0]};
	assign Mult_out = {{8{T_1[21]}},T_1[21:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_24 <= 0;
			Out2_24 <= 0;
			end
		else begin
			Out1_24 <= In1_24 + Mult_out;
			Out2_24 <= In2_24 + Mult_out;
			end
endmodule

module filt_25(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_25, In2_25, Out1_25, Out2_25);
// Value of filter coefficient is: -0.0032958984375000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_25, In2_25;
	output [29:0] Out1_25, Out2_25;
	reg [29:0] Out1_25, Out2_25;

	wire [29:0] Mult_out;

	wire [21:0] T_1;
	assign T_1 = {{{{3{CSE_I_1[18]}},CSE_I_1[18:5]}-{{1{Xin[15]}},Xin[15:0]}},CSE_I_1[4:0]};
	assign Mult_out = {{8{T_1[21]}},T_1[21:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_25 <= 0;
			Out2_25 <= 0;
			end
		else begin
			Out1_25 <= In1_25 + Mult_out;
			Out2_25 <= In2_25 + Mult_out;
			end
endmodule

module filt_26(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_26, In2_26, Out1_26, Out2_26);
// Value of filter coefficient is: -0.0034179687500000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_26, In2_26;
	output [29:0] Out1_26, Out2_26;
	reg [29:0] Out1_26, Out2_26;

	wire [29:0] Mult_out;

	assign Mult_out = {{8{CSE_I_4[18]}}, CSE_I_4[18:0], 2'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_26 <= 0;
			Out2_26 <= 0;
			end
		else begin
			Out1_26 <= In1_26 + Mult_out;
			Out2_26 <= In2_26 + Mult_out;
			end
endmodule

module filt_27(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_27, In2_27, Out1_27, Out2_27);
// Value of filter coefficient is: -0.0030517578125000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_27, In2_27;
	output [29:0] Out1_27, Out2_27;
	reg [29:0] Out1_27, Out2_27;

	wire [29:0] Mult_out;

	wire [21:0] T_1;
	assign T_1 = {{{{2{CSE_I_3[19]}},CSE_I_3[19:5]}+{{1{Xin[15]}},Xin[15:0]}},CSE_I_3[4:0]};
	assign Mult_out = {{8{T_1[21]}},T_1[21:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_27 <= 0;
			Out2_27 <= 0;
			end
		else begin
			Out1_27 <= In1_27 - Mult_out;
			Out2_27 <= In2_27 - Mult_out;
			end
endmodule

module filt_28(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_28, In2_28, Out1_28, Out2_28);
// Value of filter coefficient is: -0.0020751953125000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_28, In2_28;
	output [29:0] Out1_28, Out2_28;
	reg [29:0] Out1_28, Out2_28;

	wire [29:0] Mult_out;

	wire [20:0] T_1;
	assign T_1 = {{{{5{Xin[15]}},Xin[15:4]}+{{1{Xin[15]}},Xin[15:0]}},Xin[3:0]};
	assign Mult_out = {{9{T_1[20]}},T_1[20:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_28 <= 0;
			Out2_28 <= 0;
			end
		else begin
			Out1_28 <= In1_28 - Mult_out;
			Out2_28 <= In2_28 - Mult_out;
			end
endmodule

module filt_29(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_29, In2_29, Out1_29, Out2_29);
// Value of filter coefficient is: -0.0004882812500000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_29, In2_29;
	output [29:0] Out1_29, Out2_29;
	reg [29:0] Out1_29, Out2_29;

	wire [29:0] Mult_out;

	assign Mult_out = {{12{Xin[15]}}, Xin[15:0], 2'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_29 <= 0;
			Out2_29 <= 0;
			end
		else begin
			Out1_29 <= In1_29 - Mult_out;
			Out2_29 <= In2_29 - Mult_out;
			end
endmodule

module filt_30(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_30, In2_30, Out1_30, Out2_30);
// Value of filter coefficient is: 0.0012207031250000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_30, In2_30;
	output [29:0] Out1_30, Out2_30;
	reg [29:0] Out1_30, Out2_30;

	wire [29:0] Mult_out;

	assign Mult_out = {{10{CSE_I_1[18]}}, CSE_I_1[18:0], 1'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_30 <= 0;
			Out2_30 <= 0;
			end
		else begin
			Out1_30 <= In1_30 + Mult_out;
			Out2_30 <= In2_30 + Mult_out;
			end
endmodule

module filt_31(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_31, In2_31, Out1_31, Out2_31);
// Value of filter coefficient is: 0.0031738281250000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_31, In2_31;
	output [29:0] Out1_31, Out2_31;
	reg [29:0] Out1_31, Out2_31;

	wire [29:0] Mult_out;

	wire [20:0] T_1;
	assign T_1 = {{{{3{CSE_I_2[17]}},CSE_I_2[17:4]}+{{1{Xin[15]}},Xin[15:0]}},CSE_I_2[3:0]};
	assign Mult_out = {{8{T_1[20]}},T_1[20:0], 1'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_31 <= 0;
			Out2_31 <= 0;
			end
		else begin
			Out1_31 <= In1_31 + Mult_out;
			Out2_31 <= In2_31 + Mult_out;
			end
endmodule

module filt_32(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_32, In2_32, Out1_32, Out2_32);
// Value of filter coefficient is: 0.0047607421875000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_32, In2_32;
	output [29:0] Out1_32, Out2_32;
	reg [29:0] Out1_32, Out2_32;

	wire [29:0] Mult_out;

	wire [21:0] T_1;
	assign T_1 = {{{{2{CSE_I_3[19]}},CSE_I_3[19:5]}-{{1{Xin[15]}},Xin[15:0]}},CSE_I_3[4:0]};
	assign Mult_out = {{8{T_1[21]}},T_1[21:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_32 <= 0;
			Out2_32 <= 0;
			end
		else begin
			Out1_32 <= In1_32 - Mult_out;
			Out2_32 <= In2_32 - Mult_out;
			end
endmodule

module filt_33(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_33, In2_33, Out1_33, Out2_33);
// Value of filter coefficient is: 0.0058593750000000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_33, In2_33;
	output [29:0] Out1_33, Out2_33;
	reg [29:0] Out1_33, Out2_33;

	wire [29:0] Mult_out;

	assign Mult_out = {{7{CSE_I_2[17]}}, CSE_I_2[17:0], 4'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_33 <= 0;
			Out2_33 <= 0;
			end
		else begin
			Out1_33 <= In1_33 - Mult_out;
			Out2_33 <= In2_33 - Mult_out;
			end
endmodule

module filt_34(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_34, In2_34, Out1_34, Out2_34);
// Value of filter coefficient is: 0.0063476562500000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_34, In2_34;
	output [29:0] Out1_34, Out2_34;
	reg [29:0] Out1_34, Out2_34;

	wire [29:0] Mult_out;

	wire [20:0] T_1;
	assign T_1 = {{{{3{CSE_I_2[17]}},CSE_I_2[17:4]}+{{1{Xin[15]}},Xin[15:0]}},CSE_I_2[3:0]};
	assign Mult_out = {{7{T_1[20]}},T_1[20:0], 2'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_34 <= 0;
			Out2_34 <= 0;
			end
		else begin
			Out1_34 <= In1_34 + Mult_out;
			Out2_34 <= In2_34 + Mult_out;
			end
endmodule

module filt_35(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_35, In2_35, Out1_35, Out2_35);
// Value of filter coefficient is: 0.0056152343750000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_35, In2_35;
	output [29:0] Out1_35, Out2_35;
	reg [29:0] Out1_35, Out2_35;

	wire [29:0] Mult_out;

	wire [21:0] T_1;
	assign T_1 = {{{{2{CSE_I_3[19]}},CSE_I_3[19:5]}-{{1{Xin[15]}},Xin[15:0]}},CSE_I_3[4:0]};
	assign Mult_out = {{7{T_1[21]}},T_1[21:0], 1'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_35 <= 0;
			Out2_35 <= 0;
			end
		else begin
			Out1_35 <= In1_35 - Mult_out;
			Out2_35 <= In2_35 - Mult_out;
			end
endmodule

module filt_36(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_36, In2_36, Out1_36, Out2_36);
// Value of filter coefficient is: 0.0037841796875000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_36, In2_36;
	output [29:0] Out1_36, Out2_36;
	reg [29:0] Out1_36, Out2_36;

	wire [29:0] Mult_out;

	wire [21:0] T_1;
	assign T_1 = {{{{6{Xin[15]}},Xin[15:5]}-{{1{Xin[15]}},Xin[15:0]}},Xin[4:0]};
	assign Mult_out = {{8{T_1[21]}},T_1[21:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_36 <= 0;
			Out2_36 <= 0;
			end
		else begin
			Out1_36 <= In1_36 - Mult_out;
			Out2_36 <= In2_36 - Mult_out;
			end
endmodule

module filt_37(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_37, In2_37, Out1_37, Out2_37);
// Value of filter coefficient is: 0.0010986328125000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_37, In2_37;
	output [29:0] Out1_37, Out2_37;
	reg [29:0] Out1_37, Out2_37;

	wire [29:0] Mult_out;

	assign Mult_out = {{10{CSE_I_3[19]}}, CSE_I_3[19:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_37 <= 0;
			Out2_37 <= 0;
			end
		else begin
			Out1_37 <= In1_37 + Mult_out;
			Out2_37 <= In2_37 + Mult_out;
			end
endmodule

module filt_38(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_38, In2_38, Out1_38, Out2_38);
// Value of filter coefficient is: -0.0020751953125000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_38, In2_38;
	output [29:0] Out1_38, Out2_38;
	reg [29:0] Out1_38, Out2_38;

	wire [29:0] Mult_out;

	wire [20:0] T_1;
	assign T_1 = {{{{5{Xin[15]}},Xin[15:4]}+{{1{Xin[15]}},Xin[15:0]}},Xin[3:0]};
	assign Mult_out = {{9{T_1[20]}},T_1[20:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_38 <= 0;
			Out2_38 <= 0;
			end
		else begin
			Out1_38 <= In1_38 - Mult_out;
			Out2_38 <= In2_38 - Mult_out;
			end
endmodule

module filt_39(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_39, In2_39, Out1_39, Out2_39);
// Value of filter coefficient is: -0.0057373046875000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_39, In2_39;
	output [29:0] Out1_39, Out2_39;
	reg [29:0] Out1_39, Out2_39;

	wire [29:0] Mult_out;

	wire [21:0] T_1;
	assign T_1 = {{{{6{Xin[15]}},Xin[15:4]}+{CSE_I_2[17:0]}},Xin[3:0]};
	assign Mult_out = {{8{T_1[21]}},T_1[21:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_39 <= 0;
			Out2_39 <= 0;
			end
		else begin
			Out1_39 <= In1_39 + Mult_out;
			Out2_39 <= In2_39 + Mult_out;
			end
endmodule

module filt_40(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_40, In2_40, Out1_40, Out2_40);
// Value of filter coefficient is: -0.0090332031250000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_40, In2_40;
	output [29:0] Out1_40, Out2_40;
	reg [29:0] Out1_40, Out2_40;

	wire [29:0] Mult_out;

	wire [21:0] T_1;
	assign T_1 = {{{{3{CSE_I_1[18]}},CSE_I_1[18:5]}+{{1{Xin[15]}},Xin[15:0]}},CSE_I_1[4:0]};
	assign Mult_out = {{7{T_1[21]}},T_1[21:0], 1'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_40 <= 0;
			Out2_40 <= 0;
			end
		else begin
			Out1_40 <= In1_40 - Mult_out;
			Out2_40 <= In2_40 - Mult_out;
			end
endmodule

module filt_41(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_41, In2_41, Out1_41, Out2_41);
// Value of filter coefficient is: -0.0114746093750000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_41, In2_41;
	output [29:0] Out1_41, Out2_41;
	reg [29:0] Out1_41, Out2_41;

	wire [29:0] Mult_out;

	wire [21:0] T_1;
	assign T_1 = {{{{6{Xin[15]}},Xin[15:4]}+{CSE_I_2[17:0]}},Xin[3:0]};
	assign Mult_out = {{7{T_1[21]}},T_1[21:0], 1'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_41 <= 0;
			Out2_41 <= 0;
			end
		else begin
			Out1_41 <= In1_41 + Mult_out;
			Out2_41 <= In2_41 + Mult_out;
			end
endmodule

module filt_42(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_42, In2_42, Out1_42, Out2_42);
// Value of filter coefficient is: -0.0125732421875000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_42, In2_42;
	output [29:0] Out1_42, Out2_42;
	reg [29:0] Out1_42, Out2_42;

	wire [29:0] Mult_out;

	wire [22:0] T_1;
	assign T_1 = {{{{4{CSE_I_4[18]}},CSE_I_4[18:5]}+{CSE_I_2[17:0]}},CSE_I_4[4:0]};
	assign Mult_out = {{7{T_1[22]}},T_1[22:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_42 <= 0;
			Out2_42 <= 0;
			end
		else begin
			Out1_42 <= In1_42 + Mult_out;
			Out2_42 <= In2_42 + Mult_out;
			end
endmodule

module filt_43(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_43, In2_43, Out1_43, Out2_43);
// Value of filter coefficient is: -0.0115966796875000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_43, In2_43;
	output [29:0] Out1_43, Out2_43;
	reg [29:0] Out1_43, Out2_43;

	wire [29:0] Mult_out;

	wire [22:0] T_1;
	assign T_1 = {{{{7{Xin[15]}},Xin[15:5]}+{CSE_I_2[17:0]}},Xin[4:0]};
	assign Mult_out = {{7{T_1[22]}},T_1[22:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_43 <= 0;
			Out2_43 <= 0;
			end
		else begin
			Out1_43 <= In1_43 + Mult_out;
			Out2_43 <= In2_43 + Mult_out;
			end
endmodule

module filt_44(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_44, In2_44, Out1_44, Out2_44);
// Value of filter coefficient is: -0.0085449218750000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_44, In2_44;
	output [29:0] Out1_44, Out2_44;
	reg [29:0] Out1_44, Out2_44;

	wire [29:0] Mult_out;

	wire [21:0] T_1;
	assign T_1 = {{{{4{CSE_I_2[17]}},CSE_I_2[17:5]}-{{1{Xin[15]}},Xin[15:0]}},CSE_I_2[4:0]};
	assign Mult_out = {{7{T_1[21]}},T_1[21:0], 1'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_44 <= 0;
			Out2_44 <= 0;
			end
		else begin
			Out1_44 <= In1_44 + Mult_out;
			Out2_44 <= In2_44 + Mult_out;
			end
endmodule

module filt_45(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_45, In2_45, Out1_45, Out2_45);
// Value of filter coefficient is: -0.0030517578125000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_45, In2_45;
	output [29:0] Out1_45, Out2_45;
	reg [29:0] Out1_45, Out2_45;

	wire [29:0] Mult_out;

	wire [21:0] T_1;
	assign T_1 = {{{{2{CSE_I_3[19]}},CSE_I_3[19:5]}+{{1{Xin[15]}},Xin[15:0]}},CSE_I_3[4:0]};
	assign Mult_out = {{8{T_1[21]}},T_1[21:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_45 <= 0;
			Out2_45 <= 0;
			end
		else begin
			Out1_45 <= In1_45 - Mult_out;
			Out2_45 <= In2_45 - Mult_out;
			end
endmodule

module filt_46(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_46, In2_46, Out1_46, Out2_46);
// Value of filter coefficient is: 0.0043945312500000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_46, In2_46;
	output [29:0] Out1_46, Out2_46;
	reg [29:0] Out1_46, Out2_46;

	wire [29:0] Mult_out;

	assign Mult_out = {{8{CSE_I_3[19]}}, CSE_I_3[19:0], 2'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_46 <= 0;
			Out2_46 <= 0;
			end
		else begin
			Out1_46 <= In1_46 + Mult_out;
			Out2_46 <= In2_46 + Mult_out;
			end
endmodule

module filt_47(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_47, In2_47, Out1_47, Out2_47);
// Value of filter coefficient is: 0.0135498046875000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_47, In2_47;
	output [29:0] Out1_47, Out2_47;
	reg [29:0] Out1_47, Out2_47;

	wire [29:0] Mult_out;

	wire [23:0] T_1;
	assign T_1 = {{{{8{Xin[15]}},Xin[15:4]}+{CSE_I_3[19:0]}},Xin[3:0]};
	assign Mult_out = {{6{T_1[23]}},T_1[23:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_47 <= 0;
			Out2_47 <= 0;
			end
		else begin
			Out1_47 <= In1_47 - Mult_out;
			Out2_47 <= In2_47 - Mult_out;
			end
endmodule

module filt_48(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_48, In2_48, Out1_48, Out2_48);
// Value of filter coefficient is: 0.0238037109375000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_48, In2_48;
	output [29:0] Out1_48, Out2_48;
	reg [29:0] Out1_48, Out2_48;

	wire [29:0] Mult_out;

	wire [23:0] T_1;
	assign T_1 = {{{{6{CSE_I_2[17]}},CSE_I_2[17:6]}+{CSE_I_2[17:0]}},CSE_I_2[5:0]};
	assign Mult_out = {{6{T_1[23]}},T_1[23:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_48 <= 0;
			Out2_48 <= 0;
			end
		else begin
			Out1_48 <= In1_48 - Mult_out;
			Out2_48 <= In2_48 - Mult_out;
			end
endmodule

module filt_49(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_49, In2_49, Out1_49, Out2_49);
// Value of filter coefficient is: 0.0343017578125000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_49, In2_49;
	output [29:0] Out1_49, Out2_49;
	reg [29:0] Out1_49, Out2_49;

	wire [29:0] Mult_out;

	wire [24:0] T_1;
	assign T_1 = {{{{6{CSE_I_4[18]}},CSE_I_4[18:5]}+{CSE_I_3[19:0]}},CSE_I_4[4:0]};
	assign Mult_out = {{5{T_1[24]}},T_1[24:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_49 <= 0;
			Out2_49 <= 0;
			end
		else begin
			Out1_49 <= In1_49 + Mult_out;
			Out2_49 <= In2_49 + Mult_out;
			end
endmodule

module filt_50(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_50, In2_50, Out1_50, Out2_50);
// Value of filter coefficient is: 0.0439453125000000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_50, In2_50;
	output [29:0] Out1_50, Out2_50;
	reg [29:0] Out1_50, Out2_50;

	wire [29:0] Mult_out;

	wire [21:0] T_1;
	assign T_1 = {{{{4{CSE_I_2[17]}},CSE_I_2[17:4]}-{CSE_I_2[17:0]}},CSE_I_2[3:0]};
	assign Mult_out = {{5{T_1[21]}},T_1[21:0], 3'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_50 <= 0;
			Out2_50 <= 0;
			end
		else begin
			Out1_50 <= In1_50 + Mult_out;
			Out2_50 <= In2_50 + Mult_out;
			end
endmodule

module filt_51(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_51, In2_51, Out1_51, Out2_51);
// Value of filter coefficient is: 0.0522460937500000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_51, In2_51;
	output [29:0] Out1_51, Out2_51;
	reg [29:0] Out1_51, Out2_51;

	wire [29:0] Mult_out;

	wire [23:0] T_1;
	assign T_1 = {{{{5{CSE_I_1[18]}},CSE_I_1[18:4]}+{CSE_I_3[19:0]}},CSE_I_1[3:0]};
	assign Mult_out = {{4{T_1[23]}},T_1[23:0], 2'b0};

	always @(posedge Clk)
		if (Reset) begin
			Out1_51 <= 0;
			Out2_51 <= 0;
			end
		else begin
			Out1_51 <= In1_51 - Mult_out;
			Out2_51 <= In2_51 - Mult_out;
			end
endmodule

module filt_52(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_52, In2_52, Out1_52, Out2_52);
// Value of filter coefficient is: 0.0584716796875000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_52, In2_52;
	output [29:0] Out1_52, Out2_52;
	reg [29:0] Out1_52, Out2_52;

	wire [29:0] Mult_out;

	wire [21:0] T_1;
	assign T_1 = {{{{6{Xin[15]}},Xin[15:5]}+{{1{Xin[15]}},Xin[15:0]}},Xin[4:0]};

	wire [25:0] T_2;
	assign T_2 = {{{{4{T_1[21]}},T_1[21:9]}-{{1{Xin[15]}},Xin[15:0]}},T_1[8:0]};
	assign Mult_out = {{4{T_2[25]}},T_2[25:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_52 <= 0;
			Out2_52 <= 0;
			end
		else begin
			Out1_52 <= In1_52 - Mult_out;
			Out2_52 <= In2_52 - Mult_out;
			end
endmodule

module filt_53(Clk, Reset, Xin, CSE_I_1, CSE_I_2, CSE_I_3, CSE_I_4, In1_53, In2_53, Out1_53, Out2_53);
// Value of filter coefficient is: 0.0616455078125000
	input Clk, Reset;
	input [15:0] Xin;
	input [18:0] CSE_I_1;
	input [17:0] CSE_I_2;
	input [19:0] CSE_I_3;
	input [18:0] CSE_I_4;
	input [29:0] In1_53, In2_53;
	output [29:0] Out1_53, Out2_53;
	reg [29:0] Out1_53, Out2_53;

	wire [29:0] Mult_out;

	wire [25:0] T_1;
	assign T_1 = {{{{7{CSE_I_4[18]}},CSE_I_4[18:9]}+{{1{Xin[15]}},Xin[15:0]}},CSE_I_4[8:0]};
	assign Mult_out = {{4{T_1[25]}},T_1[25:0]};

	always @(posedge Clk)
		if (Reset) begin
			Out1_53 <= 0;
			Out2_53 <= 0;
			end
		else begin
			Out1_53 <= In1_53 + Mult_out;
			Out2_53 <= In2_53 + Mult_out;
			end
endmodule



//Top level module for filter
//This module stitches together all the submodules to form the final filter
module filter_top(Clk, Reset, Xin, Y_out);
	input Clk, Reset;
	input [15:0] Xin;
	output [28:0] Y_out;

	reg [15:0] TR_in;

	wire [18:0] CSEW_1;
	wire [17:0] CSEW_2;
	wire [19:0] CSEW_3;
	wire [18:0] CSEW_4;
	wire [29:0] TW1_0, TW2_0;
	wire [29:0] TW1_1, TW2_1;
	wire [29:0] TW1_2, TW2_2;
	wire [29:0] TW1_3, TW2_3;
	wire [29:0] TW1_4, TW2_4;
	wire [29:0] TW1_5, TW2_5;
	wire [29:0] TW1_6, TW2_6;
	wire [29:0] TW1_7, TW2_7;
	wire [29:0] TW1_8, TW2_8;
	wire [29:0] TW1_9, TW2_9;
	wire [29:0] TW1_10, TW2_10;
	wire [29:0] TW1_11, TW2_11;
	wire [29:0] TW1_12, TW2_12;
	wire [29:0] TW1_13, TW2_13;
	wire [29:0] TW1_14, TW2_14;
	wire [29:0] TW1_15, TW2_15;
	wire [29:0] TW1_16, TW2_16;
	wire [29:0] TW1_17, TW2_17;
	wire [29:0] TW1_18, TW2_18;
	wire [29:0] TW1_19, TW2_19;
	wire [29:0] TW1_20, TW2_20;
	wire [29:0] TW1_21, TW2_21;
	wire [29:0] TW1_22, TW2_22;
	wire [29:0] TW1_23, TW2_23;
	wire [29:0] TW1_24, TW2_24;
	wire [29:0] TW1_25, TW2_25;
	wire [29:0] TW1_26, TW2_26;
	wire [29:0] TW1_27, TW2_27;
	wire [29:0] TW1_28, TW2_28;
	wire [29:0] TW1_29, TW2_29;
	wire [29:0] TW1_30, TW2_30;
	wire [29:0] TW1_31, TW2_31;
	wire [29:0] TW1_32, TW2_32;
	wire [29:0] TW1_33, TW2_33;
	wire [29:0] TW1_34, TW2_34;
	wire [29:0] TW1_35, TW2_35;
	wire [29:0] TW1_36, TW2_36;
	wire [29:0] TW1_37, TW2_37;
	wire [29:0] TW1_38, TW2_38;
	wire [29:0] TW1_39, TW2_39;
	wire [29:0] TW1_40, TW2_40;
	wire [29:0] TW1_41, TW2_41;
	wire [29:0] TW1_42, TW2_42;
	wire [29:0] TW1_43, TW2_43;
	wire [29:0] TW1_44, TW2_44;
	wire [29:0] TW1_45, TW2_45;
	wire [29:0] TW1_46, TW2_46;
	wire [29:0] TW1_47, TW2_47;
	wire [29:0] TW1_48, TW2_48;
	wire [29:0] TW1_49, TW2_49;
	wire [29:0] TW1_50, TW2_50;
	wire [29:0] TW1_51, TW2_51;
	wire [29:0] TW1_52, TW2_52;
	wire [29:0] TW1_53, TW2_53;
	wire [29:0] TWend;

	filt_CSE_1 FCSE_1(TR_in, CSEW_1);
	filt_CSE_2 FCSE_2(TR_in, CSEW_2);
	filt_CSE_3 FCSE_3(TR_in, CSEW_3);
	filt_CSE_4 FCSE_4(TR_in, CSEW_4);

	filt_0 FM_0(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW2_1, TW1_1, TW2_0);
	filt_1 FM_1(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_1, TW2_2, TW1_2, TW2_1);
	filt_2 FM_2(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_2, TW2_3, TW1_3, TW2_2);
	filt_3 FM_3(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_3, TW2_4, TW1_4, TW2_3);
	filt_4 FM_4(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_4, TW2_5, TW1_5, TW2_4);
	filt_5 FM_5(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_5, TW2_6, TW1_6, TW2_5);
	filt_6 FM_6(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_6, TW2_7, TW1_7, TW2_6);
	filt_7 FM_7(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_7, TW2_8, TW1_8, TW2_7);
	filt_8 FM_8(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_8, TW2_9, TW1_9, TW2_8);
	filt_9 FM_9(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_9, TW2_10, TW1_10, TW2_9);
	filt_10 FM_10(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_10, TW2_11, TW1_11, TW2_10);
	filt_11 FM_11(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_11, TW2_12, TW1_12, TW2_11);
	filt_12 FM_12(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_12, TW2_13, TW1_13, TW2_12);
	filt_13 FM_13(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_13, TW2_14, TW1_14, TW2_13);
	filt_14 FM_14(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_14, TW2_15, TW1_15, TW2_14);
	filt_15 FM_15(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_15, TW2_16, TW1_16, TW2_15);
	filt_16 FM_16(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_16, TW2_17, TW1_17, TW2_16);
	filt_17 FM_17(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_17, TW2_18, TW1_18, TW2_17);
	filt_18 FM_18(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_18, TW2_19, TW1_19, TW2_18);
	filt_19 FM_19(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_19, TW2_20, TW1_20, TW2_19);
	filt_20 FM_20(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_20, TW2_21, TW1_21, TW2_20);
	filt_21 FM_21(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_21, TW2_22, TW1_22, TW2_21);
	filt_22 FM_22(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_22, TW2_23, TW1_23, TW2_22);
	filt_23 FM_23(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_23, TW2_24, TW1_24, TW2_23);
	filt_24 FM_24(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_24, TW2_25, TW1_25, TW2_24);
	filt_25 FM_25(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_25, TW2_26, TW1_26, TW2_25);
	filt_26 FM_26(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_26, TW2_27, TW1_27, TW2_26);
	filt_27 FM_27(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_27, TW2_28, TW1_28, TW2_27);
	filt_28 FM_28(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_28, TW2_29, TW1_29, TW2_28);
	filt_29 FM_29(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_29, TW2_30, TW1_30, TW2_29);
	filt_30 FM_30(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_30, TW2_31, TW1_31, TW2_30);
	filt_31 FM_31(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_31, TW2_32, TW1_32, TW2_31);
	filt_32 FM_32(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_32, TW2_33, TW1_33, TW2_32);
	filt_33 FM_33(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_33, TW2_34, TW1_34, TW2_33);
	filt_34 FM_34(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_34, TW2_35, TW1_35, TW2_34);
	filt_35 FM_35(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_35, TW2_36, TW1_36, TW2_35);
	filt_36 FM_36(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_36, TW2_37, TW1_37, TW2_36);
	filt_37 FM_37(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_37, TW2_38, TW1_38, TW2_37);
	filt_38 FM_38(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_38, TW2_39, TW1_39, TW2_38);
	filt_39 FM_39(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_39, TW2_40, TW1_40, TW2_39);
	filt_40 FM_40(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_40, TW2_41, TW1_41, TW2_40);
	filt_41 FM_41(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_41, TW2_42, TW1_42, TW2_41);
	filt_42 FM_42(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_42, TW2_43, TW1_43, TW2_42);
	filt_43 FM_43(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_43, TW2_44, TW1_44, TW2_43);
	filt_44 FM_44(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_44, TW2_45, TW1_45, TW2_44);
	filt_45 FM_45(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_45, TW2_46, TW1_46, TW2_45);
	filt_46 FM_46(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_46, TW2_47, TW1_47, TW2_46);
	filt_47 FM_47(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_47, TW2_48, TW1_48, TW2_47);
	filt_48 FM_48(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_48, TW2_49, TW1_49, TW2_48);
	filt_49 FM_49(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_49, TW2_50, TW1_50, TW2_49);
	filt_50 FM_50(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_50, TW2_51, TW1_51, TW2_50);
	filt_51 FM_51(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_51, TW2_52, TW1_52, TW2_51);
	filt_52 FM_52(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_52, TW2_53, TW1_53, TW2_52);
	filt_53 FM_53(Clk, Reset, TR_in, CSEW_1, CSEW_2, CSEW_3, CSEW_4, TW1_53, TWend, TWend, TW2_53);

	assign Y_out = TW2_0[28:0];

	always @(posedge Clk)
		if (Reset) TR_in <= 0;
		else TR_in <= Xin;

endmodule

